import { Select, SelectChangeEvent } from "@mui/material";
import { ReactNode } from "react";
import SelectArrowIcon from "./SelectArrowIcon";

interface Props {
  children: ReactNode;
  id: string;
  value: string;
  onChange: (e: SelectChangeEvent) => void;
}

export default function CustomSelect({ children, id, onChange, value }: Props) {
  return (
    <Select
      id={id}
      variant="outlined"
      displayEmpty
      value={value}
      onChange={onChange}
      sx={{
        "&:hover": {
          bgcolor: "#995BEE",
          color: "white",
        },
        "&:hover path": {
          stroke: "white",
        },
        color: "#7E2AEA",
        backgroundColor: "white",
        borderRadius: "8px",
        "& fieldset": {
          border: "none",
        },
        "& .MuiOutlinedInput-input": {
          fontSize: "18px",
          minHeight: "0 !important",
          lineHeight: "24px",
          pl: "33px",
          pr: "56px !important",
          py: "10px",
        },
        "& .MuiSelect-icon": {
          right: "24px",
        },
        boxShadow: `
                    0px 100px 309px rgba(210, 208, 225, 0.24), 
                    0px 41.7776px 129.093px rgba(210, 208, 225, 0.172525), 
                    0px 22.3363px 69.0192px rgba(210, 208, 225, 0.143066), 
                    0px 12.5216px 38.6916px rgba(210, 208, 225, 0.12), 
                    0px 6.6501px 20.5488px rgba(210, 208, 225, 0.0969343), 
                    0px 2.76726px 8.55082px rgba(210, 208, 225, 0.0674749)
                `,
      }}
      IconComponent={(props) => <SelectArrowIcon {...props} />}
    >
      {children}
    </Select>
  );
}
